@@ -48,13 +48,12 @@
 #' 
 #' @param method Character.
 #' Computes weighted topological overlap (\code{"wTO"} using \code{\link[qgraph]{EBICglasso}}),
-#' partial correlations (\code{"pcor"}), correlations (\code{"cor"}) or the correlated residuals
-#' from a unidimensional item response theory model (\code{"IRT"}) using \code{\link[mirt]{mirt}}.
+#' partial correlations (\code{"pcor"}), or correlations (\code{"cor"})
 #' Defaults to \code{"wTO"}
 #' 
 #' @param type Character. Type of significance.
 #' Computes significance using the standard \emph{p}-value (\code{"alpha"}),
-#' adaptive alpha \emph{p}-value (\code{\link[NetworkToolbox]{adapt.a}}), 
+#' adaptive alpha \emph{p}-value (\code{adapt.a}), 
 #' or some threshold \code{"threshold"}.
 #' Defaults to \code{"threshold"} 
 #'
@@ -73,9 +72,6 @@
 #' \item{\code{"cor"}}
 #' {.50}
 #' 
-#' \item{\code{"IRT"}}
-#' {.35}
-#' 
 #' } 
 #' 
 #' @param key Character vector.
@@ -302,17 +298,18 @@
 #' @export
 #
 # Unique Variable Analysis
-# Updated 24.10.2021
-UVA <- function(data, n = NULL,
-                model = c("glasso", "TMFG"),
-                corr = c("cor_auto", "pearson", "spearman"),
-                method = c("cor", "pcor", "wTO", "IRT"),
-                type = c("adapt", "alpha", "threshold"), sig,
-                key = NULL, reduce = TRUE, auto = TRUE, label_latent = TRUE,
-                reduce.method = c("latent", "remove", "sum"),
-                lavaan.args = list(), adhoc = TRUE,
-                plot.redundancy = FALSE, plot.args = list()
-                )
+# Updated 01.05.2022
+UVA <- function(
+  data, n = NULL,
+  model = c("glasso", "TMFG"),
+  corr = c("cor_auto", "pearson", "spearman"),
+  method = c("cor", "pcor", "wTO"),
+  type = c("adapt", "alpha", "threshold"), sig,
+  key = NULL, reduce = TRUE, auto = TRUE, label_latent = TRUE,
+  reduce.method = c("latent", "remove", "sum"),
+  lavaan.args = list(), adhoc = TRUE,
+  plot.redundancy = FALSE, plot.args = list()
+)
 {
   # Make sure data is a matrix
   data <- as.matrix(data)
@@ -335,11 +332,7 @@ UVA <- function(data, n = NULL,
   
   ## type
   if(missing(type)){
-    
     type <- "threshold"
-    
-    warning('The default for the `type` argument has changed to "threshold"')
-    
   }else{type <- tolower(match.arg(type))}
   
   ## sig
@@ -348,8 +341,7 @@ UVA <- function(data, n = NULL,
       sig <- switch(method,
                     "cor" = .50,
                     "pcor" = .35,
-                    "wto" = .25,
-                    "irt" = .35,
+                    "wto" = .25
       )
     }else{sig <- .05}
   }
@@ -364,10 +356,6 @@ UVA <- function(data, n = NULL,
     
     cormat <- data
     
-    if(method == "irt"){
-      stop('method = "IRT" requires a dataset to be input')
-    }
-    
     if(is.null(n)){
       stop("Argument 'n' must be set for square matrices")
     }
@@ -386,18 +374,17 @@ UVA <- function(data, n = NULL,
   }else{### Get n
     n <- nrow(data)
     
-    if(method != "irt"){
-      ## Compute correlation matrix
-      cormat <- switch(corr,
-                       "cor_auto" = qgraph::cor_auto(data),
-                       "pearson" = cor(data, use = "pairwise.complete.obs"),
-                       "spearman" = cor(data, method = "spearman", use = "pairwise.complete.obs")
-      )
-      ### Make sure it's positive definite
-      if(any(eigen(cormat)$values < 0)){
-        cormat <- as.matrix(Matrix::nearPD(cormat, keepDiag = TRUE)$mat)
-      }
+    ## Compute correlation matrix
+    cormat <- switch(corr,
+                     "cor_auto" = qgraph::cor_auto(data),
+                     "pearson" = cor(data, use = "pairwise.complete.obs"),
+                     "spearman" = cor(data, method = "spearman", use = "pairwise.complete.obs")
+    )
+    ### Make sure it's positive definite
+    if(any(eigen(cormat)$values < 0)){
+      cormat <- as.matrix(Matrix::nearPD(cormat, keepDiag = TRUE)$mat)
     }
+    
   }
   
   ## prepare arguments for lavaan
@@ -447,11 +434,11 @@ UVA <- function(data, n = NULL,
     auto <- FALSE
     
   }
-  
-  ## 
-  
+
   ## plot.args
-  plot.args <- GGally.args(plot.args)
+  plot.args <- suppressPackageStartupMessages(
+    GGally.args(plot.args)
+  )
   
   # Perform redundancy analysis
   process <- suppressWarnings(
@@ -471,6 +458,7 @@ UVA <- function(data, n = NULL,
     }
     
     key <- colnames(data)
+    
   }
   
   # Get names
@@ -521,7 +509,7 @@ UVA <- function(data, n = NULL,
           redundancy.process(data = reduced$data, cormat = cor.data,
                              n = n,
                              model = model,
-                             method = "wto",
+                             method = method,
                              type = "threshold", sig = .25,
                              plot.redundancy = FALSE, plot.args = plot.args)
         )
@@ -544,6 +532,7 @@ UVA <- function(data, n = NULL,
                                     reduce.method = reduce.method,
                                     lavaan.args = lavaan.args,
                                     corr = corr)
+      
       ## Run check
       ## Compute correlation matrix
       if(isSymmetric(reduced$data)){
@@ -568,12 +557,33 @@ UVA <- function(data, n = NULL,
         redundancy.process(data = reduced$data, cormat = cor.data,
                            n = n,
                            model = model,
-                           method = "wto",
+                           method = method,
                            type = "threshold", sig = sig,
                            plot.redundancy = FALSE, plot.args = plot.args)
       )
       
+      # Check for names in key
+      rename_check <- adhoc.check$redundant
+      target_names <- names(rename_check) %in% names(key)
+      if(any(target_names)){
+        names(rename_check)[target_names] <- key[names(rename_check)[target_names]]
+      }
+      
+      # Insert into adhoc.check
+      adhoc.check$redundant <- lapply(rename_check, function(x){
+        
+        target_names <- x %in% names(key) 
+        
+        if(any(target_names)){
+          x[target_names] <- key[x[target_names]]
+        }
+        
+        return(x)
+        
+      })
+      
       while(all(!is.na(adhoc.check$redundant))){
+        
         # Adhoc reductions
         reduced <- redund.adhoc.auto(node.redundant.obj = adhoc.check,
                                      node.redundant.reduced = reduced,
@@ -582,39 +592,74 @@ UVA <- function(data, n = NULL,
                                      lavaan.args = lavaan.args,
                                      corr = corr)
         
-        ## Run check
-        ## Compute correlation matrix
-        if(isSymmetric(reduced$data)){
-          cor.data <- reduced$data
+        # Check for undimensionality
+        if(ncol(reduced$data) == 1){
+          break
         }else{
           
-          sink <- capture.output(
-            cor.data <- suppressMessages(
-              suppressWarnings(
-                switch(corr,
-                       "cor_auto" = qgraph::cor_auto(reduced$data),
-                       "pearson" = cor(reduced$data, use = "pairwise.complete.obs"),
-                       "spearman" = cor(reduced$data, method = "spearman", use = "pairwise.complete.obs")
+          ## Run check
+          ## Compute correlation matrix
+          if(isSymmetric(reduced$data)){
+            cor.data <- reduced$data
+          }else{
+            
+            sink <- capture.output(
+              cor.data <- suppressMessages(
+                suppressWarnings(
+                  switch(corr,
+                         "cor_auto" = qgraph::cor_auto(reduced$data),
+                         "pearson" = cor(reduced$data, use = "pairwise.complete.obs"),
+                         "spearman" = cor(reduced$data, method = "spearman", use = "pairwise.complete.obs")
+                  )
                 )
               )
             )
+            
+          }
+          
+          adhoc.check <- suppressMessages(
+            redundancy.process(data = reduced$data, cormat = cor.data,
+                               n = n,
+                               model = model,
+                               method = "wto",
+                               type = "threshold", sig = sig,
+                               plot.redundancy = FALSE, plot.args = plot.args)
           )
           
+          # Check for names in key
+          rename_check <- adhoc.check$redundant
+          target_names <- names(rename_check) %in% names(key)
+          if(any(target_names)){
+            names(rename_check)[target_names] <- key[names(rename_check)[target_names]]
+          }
+          
+          # Insert into adhoc.check
+          adhoc.check$redundant <- lapply(rename_check, function(x){
+            
+            target_names <- x %in% names(key) 
+            
+            if(any(target_names)){
+              x[target_names] <- key[x[target_names]]
+            }
+            
+            return(x)
+            
+          })
+          
+          
         }
         
-        adhoc.check <- suppressMessages(
-          redundancy.process(data = reduced$data, cormat = cor.data,
-                             n = n,
-                             model = model,
-                             method = "wto",
-                             type = "threshold", sig = sig,
-                             plot.redundancy = FALSE, plot.args = plot.args)
-        )
-        
       }
       
       # Message user
       message("done")
+      
+      # Message user
+      if(ncol(reduced$data) == 1){
+        message(
+          "\nAfter combining local dependencies, data are determined to be unidimensional."
+        )
+      }
     
       # # Name latent variables
       # name_question <- readline(prompt = "Name latent variables? [Y/n]: ")
@@ -717,6 +762,15 @@ UVA <- function(data, n = NULL,
     
   }
   res$Methods$auto <- auto
+  
+  # Change reduced names for sum scores
+  if(reduce.method == "sum"){
+    
+    colnames(res$reduced$data) <- gsub("LV_", "SUM_", colnames(res$reduced$data))
+    row.names(res$reduced$merged) <- gsub("LV_", "SUM_", row.names(res$reduced$merged))
+    
+  }
+  
     
   # Set class
   class(res) <- "UVA"
