@@ -12,12 +12,14 @@
 #' @param IS.plot Should the plot be produced for \code{item.replication}?
 #' If \code{TRUE}, then a plot for the \code{item.replication} output will be produced.
 #' Defaults to \code{TRUE}
-#' 
+#'
+#' @param structure User specified dimensionality structure.
+#'
 #' @param ... Additional arguments.
 #' Used for deprecated arguments from previous versions of \code{\link[EGAnet]{itemStability}}
 #'
 #' @return Returns a list containing:
-#' 
+#'
 #' \item{membership}{A list containing:
 #'
 #' \itemize{
@@ -32,7 +34,7 @@
 #' {The memberships from the replicate samples in the \code{\link[EGAnet]{bootEGA}} results}
 #'    }
 #' }
-#' 
+#'
 #' \item{item.stability}{A list containing:
 #'
 #' \itemize{
@@ -74,22 +76,22 @@
 #' plot.typicalStructure = TRUE, model = "glasso", plot.type = "qgraph",
 #' type = "parametric", ncores = 2)
 #' }
-#' 
+#'
 #' # Estimate item stability statistics
 #' res <- itemStability(boot.wmt)
-#' 
+#'
 #' # Changing plot features (ggplot2)
 #' ## Changing colors (ignore warnings)
 #' ### qgraph Defaults
-#' res$plot + 
+#' res$plot +
 #'     ggplot2::scale_color_manual(values = rainbow(max(res$membership$unique)))
-#' 
+#'
 #' ### Pastel
-#' res$plot + 
+#' res$plot +
 #'     ggplot2::scale_color_brewer(palette = "Pastel1")
-#'     
+#'
 #' ## Changing Legend (ignore warnings)
-#' res$plot + 
+#' res$plot +
 #'     ggplot2::scale_color_discrete(labels = "Intelligence")
 #'
 #' @references
@@ -109,77 +111,84 @@
 #' @export
 #Item Stability function
 # Updated 27.02.2021
-# Major revamp 27.02.2021 
-itemStability <- function (bootega.obj, IS.plot = TRUE, ...){
-  
+# Major revamp 27.02.2021
+itemStability <- function (bootega.obj, IS.plot = TRUE, structure = NULL, ...){
+
   # Check for 'bootEGA' object
-  if(class(bootega.obj) != "bootEGA")
-  {stop("Input for 'bootega.obj' is not a 'bootEGA' object")}
-  
+  if(is(bootega.obj) != "bootEGA"){
+    stop("Input for 'bootega.obj' is not a 'bootEGA' object")
+  }
+
   # Get additional arguments
   add.args <- list(...)
-  
+
   # Check if 'orig.wc' has been input as an argument
   if("orig.wc" %in% names(add.args)){
-    
+
     # Give deprecation warning
     warning(
         "The 'orig.wc' argument has been deprecated in itemStability.\n\nInstead, the empirical EGA estimated in bootEGA's results is used"
     )
   }
-  
+
   # Check if 'item.freq' has been input as an argument
   if("item.freq" %in% names(add.args)){
-    
+
     # Give deprecation warning
     warning(
       "The 'item.freq' argument has been deprecated in itemStability"
     )
   }
-  
+
   # Check if 'plot.item.rep' has been input as an argument
   if("plot.item.rep" %in% names(add.args)){
-    
+
     # Give deprecation warning
     warning(
-      
+
       paste(
         "The 'plot.item.rep' argument has been deprecated in itemStability.\n\nInstead use: IS.plot =", add.args$plot.item.rep, sep = " "
       )
-      
+
     )
-    
+
     # Handle the plot appropriately
     IS.plot <- add.args$plot.item.rep
   }
-  
+
   # Message function
   message(styletext(styletext("\nItem Stability Analysis", defaults = "underline"), defaults = "bold"))
-  
+
   # Let user know results are being organized
   message("\nOrganizing data...", appendLF = FALSE)
-  
+
   # Original EGA result
   ## Network
   empirical.EGA.network <- bootega.obj$EGA$network
+
+  ## User-specified structure:
+  if(is.null(structure)==FALSE){
+    names(structure) <- names(bootega.obj$EGA$wc)
+    empirical.EGA.membership <- structure
+  }else{
   ## Community membership
   empirical.EGA.membership <- bootega.obj$EGA$wc
-  
+  }
   # Get numeric memberships
   membership.numeric <- numeric.membership(empirical.EGA.membership)
-  
+
   # Get unique memberships
   unique.membership <- unique(membership.numeric)
-  
+
   # Obtain bootstrap membership matrix
   bootstrap.membership <- simplify2array(bootega.obj$boot.wc)
-  
+
   # Homogenize memberships
   final.membership <- try(
     homogenize.membership(membership.numeric, bootstrap.membership),
     silent = TRUE
   )
-  
+
   # Error check
   if(any(class(final.membership) == "try-error")){
     return(
@@ -188,19 +197,19 @@ itemStability <- function (bootega.obj, IS.plot = TRUE, ...){
                    "itemStability")
     )
   }
-  
+
   # Let user know results are done being organized
   message("done\n")
-  
+
   # Let user know results are being computed
   message("Computing results...", appendLF = FALSE)
-  
+
   # Get proportion table
   replication.proportion <- try(
     proportion.table(final.membership),
     silent = TRUE
   )
-  
+
   # Error check
   if(any(class(replication.proportion) == "try-error")){
     return(
@@ -209,7 +218,7 @@ itemStability <- function (bootega.obj, IS.plot = TRUE, ...){
                    "itemStability")
     )
   }
-  
+
   # Adjust for missing and NA dimensions
   final.proportion <- try(
     missing.dimension.check(replication.proportion,
@@ -217,7 +226,7 @@ itemStability <- function (bootega.obj, IS.plot = TRUE, ...){
                             bootstrap.membership),
     silent = TRUE
   )
-  
+
   # Error check
   if(any(class(final.proportion) == "try-error")){
     return(
@@ -226,44 +235,44 @@ itemStability <- function (bootega.obj, IS.plot = TRUE, ...){
                    "itemStability")
     )
   }
-  
+
   # Initialize results
   results <- list()
-  
+
   # Add empirical results
   results$membership <- list()
   results$membership$empirical <- empirical.EGA.membership
   results$membership$unique <- unique.membership
   results$membership$bootstrap <- final.membership
-  
+
   # Add item stability to the results
   ## Item stability for empirical dimension
   empirical.stability <- membership.numeric
-  
+
   for(i in 1:nrow(final.proportion)){
     empirical.stability[i] <- final.proportion[i,paste(empirical.EGA.membership[i])]
   }
-  
+
   results$item.stability <- list()
   results$item.stability$empirical.dimensions <- empirical.stability
-  
+
   # Add full proportion matrix to the results
   final.proportion <- as.matrix(final.proportion)
   if(any(is.na(colnames(final.proportion))) | any(colnames(final.proportion) == "NA")){
-    
+
     final.proportion <- final.proportion[,-which(is.na(colnames(final.proportion)) | colnames(final.proportion) == "NA")]
-    
+
   }
-  
+
   results$item.stability$all.dimensions <- final.proportion
   # as.matrix() resolves unidimensional structures
-  
+
   # Plot
   results <- try(
     itemStability.plot(results, bootega.obj),
     silent = TRUE
   )
-  
+
   # Error check
   if(any(class(results) == "try-error")){
     return(
@@ -272,17 +281,17 @@ itemStability <- function (bootega.obj, IS.plot = TRUE, ...){
                    "itemStability")
     )
   }
-  
+
   # Reorder empirical and all dimensions stability
   results$item.stability$empirical.dimensions <- results$item.stability$empirical.dimensions[as.character(results$plot$data$Item)]
   results$item.stability$all.dimensions <- results$item.stability$all.dimensions[as.character(results$plot$data$Item),]
-  
+
   # Compute network loadings
   loadings <- try(
     itemStability.loadings(results, bootega.obj),
     silent = TRUE
   )
-  
+
   # Error check
   if(any(class(loadings) == "try-error")){
     return(
@@ -291,25 +300,25 @@ itemStability <- function (bootega.obj, IS.plot = TRUE, ...){
                    "itemStability")
     )
   }
-  
+
   # Insert loadings into results
   results$mean.loadings <- loadings
-  
+
   # Reorder mean loadings
   results$mean.loadings <- results$mean.loadings[as.character(results$plot$data$Item),]
-  
+
   # Let user know results are done being organized
   message("done\n")
-  
+
   # Set class
   class(results) <- "itemStability"
-  
+
   # Plot to user?
   if(IS.plot){
     plot(results$plot)
   }
-  
+
   return(results)
-  
+
 }
 #----
