@@ -69,6 +69,78 @@ print.dynEGA<- function(x, ...) {
   print(x$dynEGA$dim.variables)
 }
 
+#Print Measurement Invariance----
+# Updated 10.02.2022
+#' @export
+print.invariance <- function(x, ...) {
+  print(x$results, row.names = FALSE)
+  cat("---\n")
+  cat("Signif. code: 0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 'n.s.' 1")
+}
+
+#Print Hierarchical EGA----
+# Updated 09.05.2022
+#' @export
+print.hierEGA <- function(x, ...) {
+  
+  # Print lower order communities
+  cat(paste(
+    "Lower order communities:",
+    x$hierarchical$lower_order$n.dim,
+    "\n\n"
+  ))
+  print(x$hierarchical$lower_order$wc)
+  
+  # Print higher order communities
+  cat(
+    paste(
+      "\nHigher order communities:",
+      x$hierarchical$higher_order$EGA$n.dim,
+      "\n\n"
+    )
+  )
+  print(x$hierarchical$higher_order$EGA$wc)
+  
+  # Print methods
+  cat("\nMethods:\n")
+  
+  ## Set up methods
+  methods.matrix <- matrix(
+    nrow = 7, ncol = 1
+  )
+  row.names(methods.matrix) <- c(
+    "Correlations =",
+    "Model =",
+    "Algorithm =",
+    "Unidimensional Method =",
+    "Scores =",
+    "Consensus Method =",
+    "Consensus Iterations ="
+  )
+  colnames(methods.matrix) <- ""
+  
+  methods.matrix["Correlations =",] <- ifelse(
+    x$hierarchical$Methods$corr == "cor_auto",
+    "auto (from qgraph)",
+    x$hierarchical$Methods$corr
+  )
+  methods.matrix["Model =",] <- x$hierarchical$Methods$model
+  methods.matrix["Algorithm =",] <- x$hierarchical$Methods$algorithm
+  methods.matrix["Unidimensional Method =",] <- ifelse(
+    x$hierarchical$Methods$uni.method == "LE",
+    "leading eigenvalue",
+    "expand correlation matrix"
+  )
+  methods.matrix["Scores =",] <- x$hierarchical$Methods$scores
+  methods.matrix["Consensus Method =",] <- gsub(
+    "_", " ", x$hierarchical$Methods$consensus.method
+  )
+  methods.matrix["Consensus Iterations =",] <- x$hierarchical$Methods$consensus.iter
+  
+  print(methods.matrix, quote = FALSE)
+  
+}
+
 # PLOTS----
 # Updated 16.06.2021
 #' @export
@@ -128,7 +200,7 @@ plot.bootEGA <- function(x, plot.type = c("GGally","qgraph"),
                                          ncol = ncol(x$typicalGraph$graph)))
     
     # Layout "Spring"
-    graph1 <- NetworkToolbox::convert2igraph(x$typicalGraph$graph)
+    graph1 <- convert2igraph(x$typicalGraph$graph)
     edge.list <- igraph::as_edgelist(graph1)
     layout.spring <- qgraph::qgraph.layout.fruchtermanreingold(edgelist = edge.list,
                                                                weights =
@@ -287,7 +359,7 @@ plot.dynEGA.Groups <- function(x, ncol, nrow, title = "", plot.type = c("GGally"
                                            ncol = ncol(x$dynEGA[[i]]$network)))
       
       # Layout "Spring"
-      graph1[[i]] <- NetworkToolbox::convert2igraph(x$dynEGA[[i]]$network)
+      graph1[[i]] <- convert2igraph(x$dynEGA[[i]]$network)
       edge.list[[i]] <- igraph::as_edgelist(graph1[[i]])
       layout.spring[[i]] <- qgraph::qgraph.layout.fruchtermanreingold(edgelist = edge.list[[i]],
                                                                       weights =
@@ -436,7 +508,7 @@ plot.dynEGA.Individuals <- function(x, title = "",  id = NULL, plot.type = c("GG
                                          ncol = ncol(x$dynEGA[[id]]$network)))
     
     # Layout "Spring"
-    graph1 <- NetworkToolbox::convert2igraph(x$dynEGA[[id]]$network)
+    graph1 <- convert2igraph(x$dynEGA[[id]]$network)
     edge.list <- igraph::as_edgelist(graph1)
     layout.spring <- qgraph::qgraph.layout.fruchtermanreingold(edgelist = edge.list,
                                                                weights =
@@ -591,7 +663,7 @@ plot.dynEGA <- function(x, title = "", plot.type = c("GGally","qgraph"),
                                          ncol = ncol(x$dynEGA$network)))
     
     # Layout "Spring"
-    graph1 <- NetworkToolbox::convert2igraph(x$dynEGA$network)
+    graph1 <- convert2igraph(x$dynEGA$network)
     edge.list <- igraph::as_edgelist(graph1)
     layout.spring <- qgraph::qgraph.layout.fruchtermanreingold(edgelist = edge.list,
                                                                weights =
@@ -692,7 +764,7 @@ plot.dynEGA <- function(x, title = "", plot.type = c("GGally","qgraph"),
 }
 
 # Plot EGA----
-# Updated 28.07.2021
+# Updated 07.02.2022
 #' @export
 plot.EGA <- function(x,  title = "", plot.type = c("GGally","qgraph"),
                      plot.args = list(), produce = TRUE, ...){
@@ -710,141 +782,151 @@ plot.EGA <- function(x,  title = "", plot.type = c("GGally","qgraph"),
     color.palette <- plot.args$color.palette
   }
   
+  ## Check for sum
+  sum_nodes <- sum(x$network)
   
-  ### Plot ###
-  if(plot.type == "qgraph"){
-    ega.plot <- qgraph::qgraph(x$network, layout = "spring", vsize = plot.args$vsize, groups = as.factor(x$wc), ...)
-  }else if(plot.type == "GGally"){
+  if(sum_nodes != 0){
     
-    # Insignificant values (keeps ggnet2 from erroring out)
-    x$network <- ifelse(abs(as.matrix(x$network)) <= .00001, 0, as.matrix(x$network))
-    
-    if(exists("legend.names")){
-      for(l in 1:length(unique(legend.names))){
-        x$wc[x$wc == l] <- legend.names[l]
+    ### Plot ###
+    if(plot.type == "qgraph"){
+      ega.plot <- qgraph::qgraph(x$network, layout = "spring", vsize = plot.args$vsize, groups = as.factor(x$wc), ...)
+    }else if(plot.type == "GGally"){
+      
+      # Insignificant values (keeps ggnet2 from erroring out)
+      x$network <- ifelse(abs(as.matrix(x$network)) <= .00001, 0, as.matrix(x$network))
+      
+      if(exists("legend.names")){
+        for(l in 1:length(unique(legend.names))){
+          x$wc[x$wc == l] <- legend.names[l]
+        }
       }
+      
+      # Reorder network and communities
+      x$network <- x$network[order(x$wc), order(x$wc)]
+      x$wc <- x$wc[order(x$wc)]
+      
+      # weighted  network
+      network1 <- network::network(x$network,
+                                   ignore.eval = FALSE,
+                                   names.eval = "weights",
+                                   directed = FALSE)
+      
+      network::set.vertex.attribute(network1, attrname= "Communities", value = x$wc)
+      network::set.vertex.attribute(network1, attrname= "Names", value = network::network.vertex.names(network1))
+      network::set.edge.attribute(network1, "color", ifelse(network::get.edge.value(network1, "weights") > 0, plot.args$edge.color[1], plot.args$edge.color[2]))
+      network::set.edge.attribute(network1, "line", ifelse(network::get.edge.value(network1, "weights") > 0, plot.args$edge.lty[1], plot.args$edge.lty[2]))
+      network::set.edge.value(network1,attrname="AbsWeights",value=abs(x$network))
+      network::set.edge.value(network1,attrname="ScaledWeights",
+                              value=matrix(rescale.edges(x$network, plot.args$edge.size),
+                                           nrow = nrow(x$network),
+                                           ncol = ncol(x$network)))
+      
+      # Layout "Spring"
+      graph1 <- convert2igraph(x$network)
+      edge.list <- igraph::as_edgelist(graph1)
+      layout.spring <- qgraph::qgraph.layout.fruchtermanreingold(edgelist = edge.list,
+                                                                 weights =
+                                                                   abs(igraph::E(graph1)$weight/max(abs(igraph::E(graph1)$weight)))^2,
+                                                                 vcount = ncol(x$network))
+      
+      
+      set.seed(1234)
+      plot.args$net <- network1
+      plot.args$node.color <- "Communities"
+      plot.args$node.alpha <- plot.args$alpha
+      plot.args$node.shape <- plot.args$shape
+      node.size <- plot.args$node.size
+      plot.args$node.size <- 0
+      plot.args$color.palette <- NULL
+      plot.args$palette <- NULL
+      plot.args$edge.color <- "color"
+      plot.args$edge.lty <- "line"
+      plot.args$edge.size <- "ScaledWeights"
+      
+      lower <- abs(x$network[lower.tri(x$network)])
+      non.zero <- sqrt(lower[lower != 0])
+      
+      plot.args$edge.alpha <- non.zero
+      plot.args$mode <- layout.spring
+      plot.args$label <- colnames(x$network)
+      plot.args$node.label <- rep("", ncol(x$network))
+      if(plot.args$label.size == "max_size/2"){plot.args$label.size <- plot.args$size/2}
+      if(plot.args$edge.label.size == "max_size/2"){plot.args$edge.label.size <- plot.args$size/2}
+      
+      palette <- color_palette_EGA(color.palette, as.numeric(factor(x$wc)))
+      palette <- ifelse(is.na(palette), "white", palette)
+      
+      ega.plot <- suppressWarnings(
+        suppressMessages(
+          do.call(GGally::ggnet2, plot.args) + 
+            ggplot2::theme(legend.title = ggplot2::element_blank())
+        )
+      )
+      
+      name <- colnames(x$network)
+      
+      name.split <- lapply(name, function(x){
+        unlist(strsplit(x, split = " "))
+      })
+      
+      name <- unlist(
+        lapply(name.split, function(x){
+          
+          len <- length(x)
+          
+          if(len > 1){
+            
+            add.line <- round(len / 2)
+            
+            paste(
+              paste(x[1:add.line], collapse = " "),
+              paste(x[(add.line+1):length(x)], collapse = " "),
+              sep = "\n"
+            )
+            
+          }else{x}
+          
+        })
+      )
+      
+      # Border color
+      if(all(color.palette == "grayscale" |
+             color.palette == "greyscale" |
+             color.palette == "colorblind")){
+        border.color <- ifelse(palette == "white", "white", "black")
+      }else{border.color <- palette}
+      
+      # Custom nodes: transparent insides and dark borders
+      ega.plot <- ega.plot + 
+        ggplot2::geom_point(ggplot2::aes(color = "color"), size = node.size,
+                            color = border.color,
+                            shape = 1, stroke = 1.5, alpha = .8) +
+        ggplot2::geom_point(ggplot2::aes(color = "color"), size = node.size + .5,
+                            color = palette,
+                            shape = 19, alpha = plot.args$alpha) +
+        ggplot2::geom_text(ggplot2::aes(label = name), color = "black", size = plot.args$label.size) +
+        ggplot2::guides(
+          color = ggplot2::guide_legend(override.aes = list(
+            color = unique(palette),
+            size = node.size,
+            alpha = plot.args$alpha,
+            stroke = 1.5
+          ))
+        )
+      
     }
     
-    # Reorder network and communities
-    x$network <- x$network[order(x$wc), order(x$wc)]
-    x$wc <- x$wc[order(x$wc)]
+    set.seed(NULL)
     
-    # weighted  network
-    network1 <- network::network(x$network,
-                                 ignore.eval = FALSE,
-                                 names.eval = "weights",
-                                 directed = FALSE)
-    
-    network::set.vertex.attribute(network1, attrname= "Communities", value = x$wc)
-    network::set.vertex.attribute(network1, attrname= "Names", value = network::network.vertex.names(network1))
-    network::set.edge.attribute(network1, "color", ifelse(network::get.edge.value(network1, "weights") > 0, plot.args$edge.color[1], plot.args$edge.color[2]))
-    network::set.edge.attribute(network1, "line", ifelse(network::get.edge.value(network1, "weights") > 0, plot.args$edge.lty[1], plot.args$edge.lty[2]))
-    network::set.edge.value(network1,attrname="AbsWeights",value=abs(x$network))
-    network::set.edge.value(network1,attrname="ScaledWeights",
-                            value=matrix(rescale.edges(x$network, plot.args$edge.size),
-                                         nrow = nrow(x$network),
-                                         ncol = ncol(x$network)))
-    
-    # Layout "Spring"
-    graph1 <- NetworkToolbox::convert2igraph(x$network)
-    edge.list <- igraph::as_edgelist(graph1)
-    layout.spring <- qgraph::qgraph.layout.fruchtermanreingold(edgelist = edge.list,
-                                                               weights =
-                                                                 abs(igraph::E(graph1)$weight/max(abs(igraph::E(graph1)$weight)))^2,
-                                                               vcount = ncol(x$network))
-    
-    
-    set.seed(1234)
-    plot.args$net <- network1
-    plot.args$node.color <- "Communities"
-    plot.args$node.alpha <- plot.args$alpha
-    plot.args$node.shape <- plot.args$shape
-    node.size <- plot.args$node.size
-    plot.args$node.size <- 0
-    plot.args$color.palette <- NULL
-    plot.args$palette <- NULL
-    plot.args$edge.color <- "color"
-    plot.args$edge.lty <- "line"
-    plot.args$edge.size <- "ScaledWeights"
-    
-    lower <- abs(x$network[lower.tri(x$network)])
-    non.zero <- sqrt(lower[lower != 0])
-    
-    plot.args$edge.alpha <- non.zero
-    plot.args$mode <- layout.spring
-    plot.args$label <- colnames(x$network)
-    plot.args$node.label <- rep("", ncol(x$network))
-    if(plot.args$label.size == "max_size/2"){plot.args$label.size <- plot.args$size/2}
-    if(plot.args$edge.label.size == "max_size/2"){plot.args$edge.label.size <- plot.args$size/2}
-    
-    palette <- color_palette_EGA(color.palette, as.numeric(factor(x$wc)))
-    palette <- ifelse(is.na(palette), "white", palette)
-    
-    ega.plot <- suppressWarnings(
-      suppressMessages(
-        do.call(GGally::ggnet2, plot.args) + 
-          ggplot2::theme(legend.title = ggplot2::element_blank())
-      )
-    )
-    
-    name <- colnames(x$network)
-    
-    name.split <- lapply(name, function(x){
-      unlist(strsplit(x, split = " "))
-    })
-    
-    name <- unlist(
-      lapply(name.split, function(x){
-        
-        len <- length(x)
-        
-        if(len > 1){
-          
-          add.line <- round(len / 2)
-          
-          paste(
-            paste(x[1:add.line], collapse = " "),
-            paste(x[(add.line+1):length(x)], collapse = " "),
-            sep = "\n"
-          )
-          
-        }else{x}
-        
-      })
-    )
-    
-    # Border color
-    if(all(color.palette == "grayscale" |
-           color.palette == "greyscale" |
-           color.palette == "colorblind")){
-      border.color <- ifelse(palette == "white", "white", "black")
-    }else{border.color <- palette}
-    
-    # Custom nodes: transparent insides and dark borders
-    ega.plot <- ega.plot + 
-      ggplot2::geom_point(ggplot2::aes(color = "color"), size = node.size,
-                          color = border.color,
-                          shape = 1, stroke = 1.5, alpha = .8) +
-      ggplot2::geom_point(ggplot2::aes(color = "color"), size = node.size + .5,
-                          color = palette,
-                          shape = 19, alpha = plot.args$alpha) +
-      ggplot2::geom_text(ggplot2::aes(label = name), color = "black", size = plot.args$label.size) +
-      ggplot2::guides(
-        color = ggplot2::guide_legend(override.aes = list(
-          color = unique(palette),
-          size = node.size,
-          alpha = plot.args$alpha,
-          stroke = 1.5
-        ))
-      )
+    if(isTRUE(produce)){
+      plot(ega.plot)
+    }else{return(ega.plot)}
     
+  }else{
+    message("Network is empty. No plot produced.")
   }
   
-  set.seed(NULL)
   
-  if(isTRUE(produce)){
-    plot(ega.plot)
-  }else{return(ega.plot)}
 }
 
 # Plot EGA.fit----
@@ -868,6 +950,84 @@ plot.NetLoads <- function(x, ...) {
   plot(x$plot)
 }
 
+# Plot invariance----
+# Updated 10.02.2022
+#' @export
+plot.invariance <- function(
+  x, title = "", labels = NULL,
+  rows, columns, plot.type = c("GGally","qgraph"),
+  plot.args = list(), ...
+)
+{
+  # Obtain structure
+  structure <- x$memberships
+  
+  # Prepare EGA results for plots
+  input_EGA <- lapply(x$groups$EGA, function(x){
+    
+    # Make class 'EGA'
+    class(x) <- "EGA"
+    
+    # Return list
+    return(x)
+    
+  })
+  
+  # Set structure
+  input_EGA <- lapply(input_EGA, function(x){
+    
+    # Set structure
+    x$wc <- structure
+    
+    # Return list
+    return(x)
+    
+  })
+  
+  # Check for labels
+  if(is.null(labels)){
+    labels <- names(input_EGA)
+  }
+  
+  # Check for rows
+  if(missing(rows)){
+    rows <- 1
+  }
+  
+  # Check for columns
+  if(missing(columns)){
+    columns <- length(input_EGA)
+  }
+  
+  # Check for plot type
+  if(missing(plot.type)){
+    plot.type <- "GGally"
+  }else{
+    plot.type <- match.arg(plot.type)
+  }
+  
+  # Set up plot arguments
+  if(any(x$results$p <= .05)){
+    
+    # Check for "alpha" in plot.args
+    if(!"alpha" %in% names(plot.args)){
+      plot.args$alpha <- ifelse(
+        x$results$p <= .05, .8, .2
+      )
+    }
+    
+  }
+  
+  # Obtain plots
+  plots <- compare.EGA.plots(
+    input_list = input_EGA,
+    labels = labels, rows = rows,
+    columns = columns, plot.type = plot.type,
+    plot.args = plot.args
+  )
+  
+}
+
 #Plot CFA----
 # Updated 02.05.2020
 #' @export
